@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Create network transition chord progressions
 
-our $VERSION = '0.0302';
+our $VERSION = '0.0303';
 
 use Data::Dumper::Compact qw(ddc);
 use Graph::Directed;
@@ -212,13 +212,14 @@ sub _full_keys {
 sub _tt_sub {
     my ($self, $scale, $chords, $n) = @_;
 
-    my @fnotes = get_scale_notes('C', 'chromatic', 0, 'b');
-    my @snotes = get_scale_notes('C', 'chromatic');
-    my %ftritone = map { $fnotes[$_] => $fnotes[($_ + 6) % @fnotes] } 0 .. $#fnotes;
-    my %stritone = map { $snotes[$_] => $snotes[($_ + 6) % @snotes] } 0 .. $#snotes;
-
     my $note;
+
     if ($n =~ /t/) {
+        my @fnotes = get_scale_notes('C', 'chromatic', 0, 'b');
+        my @snotes = get_scale_notes('C', 'chromatic');
+        my %ftritone = map { $fnotes[$_] => $fnotes[($_ + 6) % @fnotes] } 0 .. $#fnotes;
+        my %stritone = map { $snotes[$_] => $snotes[($_ + 6) % @snotes] } 0 .. $#snotes;
+
         $n =~ s/t//;
         $note = $ftritone{ $scale->[$n - 1] } || $stritone{ $scale->[$n - 1] };
         print "Tritone: $scale->[$n - 1] => $note\n" if $self->verbose;
@@ -279,7 +280,7 @@ Music::Chord::Progression - Create network transition chord progressions
 
 =head1 VERSION
 
-version 0.0302
+version 0.0303
 
 =head1 SYNOPSIS
 
@@ -289,13 +290,16 @@ version 0.0302
 
   my $chords = $prog->generate;
 
-  my $chord = $prog->substitution('m'); # m7
+  my $chord = $prog->substitution('m'); # m7 or mM7
 
 =head1 DESCRIPTION
 
 C<Music::Chord::Progression> creates network transition chord
 progressions.
 
+Also this module can perform limited jazz chord substitutions, if
+requested in the constructor.
+
 =head1 ATTRIBUTES
 
 =head2 max
@@ -407,11 +411,15 @@ Default: C<0>
 
 Rules:
 
-  * Any chord can be changed to a dominant
+=over 4
 
-  * Any dominant chord can be changed to a 9, 11, or 13
+=item Any chord can be changed to a dominant
 
-  * Any chord can be changed to a chord a tritone away
+=item Any dominant chord can be changed to a 9, 11, or 13
+
+=item Any chord can be changed to a chord a tritone away
+
+=back
 
 =head2 sub_cond
 
@@ -428,13 +436,13 @@ Default: C<0>
 
 =head2 graph
 
-The network transition graph.
+The network transition L<Graph> object.
 
 Default: C<Graph::Directed>
 
 =head2 verbose
 
-Show the progress of the B<generate> and B<substitution> methods.
+Show B<generate> and B<substitute> progress.
 
 =head1 METHODS
 
